==> haskell-hinotify-0.4.2-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hinotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hinotify
version:              0.4.2
visibility:           public
id:                   hinotify-0.4.2-9roxiu2doeuIA7zQoMUCLo
key:                  hinotify-0.4.2-9roxiu2doeuIA7zQoMUCLo
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  cd6a836ee1a4938450178ae4127d6e8b
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hinotify
hs-libraries:         HShinotify-0.4.2-9roxiu2doeuIA7zQoMUCLo
includes:             sys/inotify.h
depends:
    async-2.2.5-89i67iIGdTbKBr8gVHfQyZ base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hinotify-0.4.2-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hinotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hinotify
version:              0.4.2
visibility:           public
id:                   hinotify-0.4.2-ACqCnJKagnY8qhogKG7PNX
key:                  hinotify-0.4.2-ACqCnJKagnY8qhogKG7PNX
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  a548543a5a7292a08306f610b803d050
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hinotify
hs-libraries:         HShinotify-0.4.2-ACqCnJKagnY8qhogKG7PNX
includes:             sys/inotify.h
depends:
    async-2.2.5-LqkzH7L8HyYHud0cQFVYjz base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
